#
# spec file for package ghc-fixed-vector
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name fixed-vector
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.0.0
Release:        lp150.1.8
Summary:        Generic vectors with statically known size
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
%if %{with tests}
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-filemanip-devel
%endif

%description
Generic library for vectors with statically known size. Implementation is based
on
<http://unlines.wordpress.com/2010/11/15/generics-for-small-fixed-size-vectors/>
Same functions could be used to work with both ADT based vector like

> data Vec3 a = a a a

Tuples are vectors too:

>>> sum (1,2,3) 6

Vectors which are represented internally by arrays are provided by library.
Both boxed and unboxed arrays are supported.

Library is structured as follows:

* Data.Vector.Fixed Generic API. It's suitable for both ADT-based vector like
Complex and array-based ones.

* Data.Vector.Fixed.Cont Continuation based vectors. Internally all functions
use them.

* Data.Vector.Fixed.Mutable Type classes for array-based implementation and API
for working with mutable state.

* Data.Vector.Fixed.Unboxed Unboxed vectors.

* Data.Vector.Fixed.Boxed Boxed vector which can hold elements of any type.

* Data.Vector.Fixed.Storable Unboxed vectors of Storable types.

* Data.Vector.Fixed.Primitive Unboxed vectors based on pritimive package.

* Data.Vector.Fixed.Monomorphic Wrappers for monomorphic vectors.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.9.0.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.1.0 revision 0 with cabal2obs.
